==> kdepim-4.14.10.tar.xz: kdepim-4.14.10/mailcommon/filter/filteractions/filteractionexec.cpp <==
/*
 * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#include "filteractionexec.h"

#include <KDE/KLocale>

using namespace MailCommon;

FilterActionExec::FilterActionExec( QObject *parent )
    : FilterActionWithCommand( QLatin1String("execute"), i18n( "Execute Command" ), parent )
{
}

FilterAction::ReturnCode FilterActionExec::process(ItemContext &context , bool) const
{
    return FilterActionWithCommand::genericProcess( context, false ); // ignore output
}

SearchRule::RequiredPart FilterActionExec::requiredPart() const
{
    return SearchRule::CompleteMessage;
}

FilterAction* FilterActionExec::newAction()
{
    return new FilterActionExec();
}

QString FilterActionExec::informationAboutNotValidAction() const
{
    //KF5 add i18n
    return QLatin1String("No action defined.");
}

==> kdepim-15.08.3.tar.xz: kdepim-15.08.3/mailcommon/filter/filteractions/filteractionexec.cpp <==
/*
 * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#include "filteractionexec.h"

#include <KLocalizedString>

using namespace MailCommon;

FilterActionExec::FilterActionExec(QObject *parent)
    : FilterActionWithCommand(QStringLiteral("execute"), i18n("Execute Command"), parent)
{
}

FilterAction::ReturnCode FilterActionExec::process(ItemContext &context , bool) const
{
    return FilterActionWithCommand::genericProcess(context, false);   // ignore output
}

SearchRule::RequiredPart FilterActionExec::requiredPart() const
{
    return SearchRule::CompleteMessage;
}

FilterAction *FilterActionExec::newAction()
{
    return new FilterActionExec();
}

QString FilterActionExec::informationAboutNotValidAction() const
{
    return i18n("No action defined.");
}
